# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.arduino._arduino_leonardo_digital_input import ArduinoLeonardoDigitalInput as _ArduinoLeonardoDigitalInput


class ArduinoLeonardoDigitalInput(_ArduinoLeonardoDigitalInput):
    """
    ``ArduinoLeonardoDigitalInput`` reads inputs (on pins 0 .. 13) and counts edges (on pins 0, 1, 2 and 3) using pin
    change interrupts on Arduino Leonardo.

    Serial connection: 115200 baud, 8N1.
    """

    def __init__(self, port, resetOnInit=True, timeout=0.5):
        """
        Args:
            port (str): the com port the Arduino Leonardo listens to running the digital input application.
            resetOnInit=True (bool): reset internal edge counters on initialization.
            timeout=0.5 (float): the timeout for serial communication in seconds.

        Usage::

            di = ArduinoLeonardoDigitalInput("COM4")
            print("Id:", di.getId())
            print("Version:", di.getVersion())
            data = di.get()
            print(data # a dictionary containing all data)

        All entries in ``data`` starting with ``"d"`` are digital input states, ie. ``0`` or ``1``.
        All entries in ``data`` starting with ``"c"`` are edge counts, ie. ``unsigned long int``.
        Edge counts can be reset using :py:func:`~htf.arduino.ArduinoLeonardoDigitalInput.reset`.
        """
        return super(ArduinoLeonardoDigitalInput, self).__init__(port=port, resetOnInit=resetOnInit, timeout=timeout)

    def close(self):
        """
        Close serial connection.
        """
        return super(ArduinoLeonardoDigitalInput, self).close()

    def get(self):
        """
        Get current data, ie. digital input states and edge counts.

        Returns:
            dict: the current data containing digital port states and counter values.
                E.g. {'d0':1,'d1':1,'d2':0,'d3':1,'d4':1,'d5':1,'d6':1,'d7':1,'d8':1,'d9':1,'d10':1,'d11':1,'d12':1,
                'd13':1,'c0':0,'c1':0,'c2':77,'c3':102}
        """
        return super(ArduinoLeonardoDigitalInput, self).get()

    def getVersion(self):
        """
        Get software version.

        Returns:
            str: the software version.
        """
        return super(ArduinoLeonardoDigitalInput, self).getVersion()

    def reset(self):
        """
        Reset all edge counters.
        """
        return super(ArduinoLeonardoDigitalInput, self).reset()
