# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.communication._pluggable_notifier import PluggableNotifier as _PluggableNotifier


class PluggableNotifier(_PluggableNotifier):
    """
    ``PluggableNotifier`` implements an observer pattern.
    Subjects can register tuples consisting of executable filter expressions
    and callbacks to be notified about events.

    There is a method to enqueue new items and a thread to
    apply filters on items. Communication between
    method and thread is done via a queue.

    ``PluggableNotififer`` extends :py:class:`threading.Thread`.
    """

    def __init__(self, verbosity=0, raiseExceptions=False, filterExceptionHandler=None, callbackExceptionHandler=None):
        """
        Args:
            verbosity (int): if set to 1 debug messages are printed to stdout
            raiseExceptions (bool): if set to ``True`` exceptions are raised
                if a filter expression or a callback raises an exception.
                This may be used for debugging. In case of an exception
                :func:`~htf.communication.PluggableNotifier.stop` is called so
                no further items can be put in.
            filterExceptionHandler (None or callable): a callback that is
                called to handle a raised exception in a filter expression.
                If the ``filterExceptionHandler`` returns ``True`` the
                exception is not raised afterwards. Else the exception handler
                raises the catched exception and stopps the thread.
                The supplied handler musst accept ``name`` and ``item``
                arguments. ``name`` is the callback name supplied by
                :meth:`~htf.communication.PluggableNotifier.register` and
                ``item`` is the supplied item from
                :meth:`~htf.communication.PluggableNotifier.input`.
            callbackExceptionHandler (None or callable): a callback that is
                called to handle a raised exception in a callback.
                If the ``callbackExceptionHandler`` returns ``True`` the
                exception is not raised afterwards. Else the exception handler
                raises the catched exception and stopps the thread.
                The supplied handler musst accept ``name`` and ``item``
                arguments. ``name`` is the callback name supplied by
                :meth:`~htf.communication.PluggableNotifier.register` and
                ``item`` is the supplied item from
                :meth:`~htf.communication.PluggableNotifier.input`.
        """
        return super(PluggableNotifier, self).__init__(verbosity=verbosity, raiseExceptions=raiseExceptions,
                                                       filterExceptionHandler=filterExceptionHandler,
                                                       callbackExceptionHandler=callbackExceptionHandler)

    def getFilterNames(self):
        """
        Get the filter names.

        Returns:
            list of str: a sorted list containing the filter names.
        """
        return super(PluggableNotifier, self).getFilterNames()

    def getName(self):
        return super(PluggableNotifier, self).getName()

    def input(self, item):
        """
        Input an ``item`` to be used with all registered subjects.

        Args:
            item: an item to be processed.

        Raises:
            RuntimeError: if :func:`~htf.communication.PluggableNotifier.stop`
            was called before
        """
        return super(PluggableNotifier, self).input(item=item)

    def isAlive(self):
        """
        Return whether the thread is alive.

        This method returns True just before the run() method starts until just
        after the run() method terminates. The module function enumerate()
        returns a list of all alive threads.
        """
        return super(PluggableNotifier, self).isAlive()

    def isDaemon(self):
        return super(PluggableNotifier, self).isDaemon()

    def is_alive(self):
        """
        Return whether the thread is alive.

        This method returns True just before the run() method starts until just
        after the run() method terminates. The module function enumerate()
        returns a list of all alive threads.
        """
        return super(PluggableNotifier, self).is_alive()

    def join(self, timeout=1.0):
        """
        Wait until the thread ends.

        Args:
            timeout (float): the timeout in seconds. Default: 1.0 seconds.
        """
        return super(PluggableNotifier, self).join(timeout=timeout)

    def register(self, name, filterExpression, callback):
        """
        Register a tuple of `name`, `filterExpression` and a `callback`.

        Args:
            name (str): a name for the tuple (for debugging,
                see ``verbosity``).
            filterExpression (callable): a callable filter expression
                (see :py:mod:`htf.filters` for more information) or
                a method that is called.
                ``filterExpression`` is called with the ``item`` from
                :func:`input` as a parameter.
                If ``filterExpression`` returns `True` the callback is called
                with the same `item`.
            callback (callable): a callable object that is called in case
                ``filterExpression(item)`` returns ``True``.
        """
        return super(PluggableNotifier, self).register(name=name, filterExpression=filterExpression, callback=callback)

    def run(self):
        """
        Method representing the thread's activity.

        You may override this method in a subclass. The standard run() method
        invokes the callable object passed to the object's constructor as the
        target argument, if any, with sequential and keyword arguments taken
        from the args and kwargs arguments, respectively.
        """
        return super(PluggableNotifier, self).run()

    def setDaemon(self, daemonic):
        return super(PluggableNotifier, self).setDaemon(daemonic=daemonic)

    def setName(self, name):
        return super(PluggableNotifier, self).setName(name=name)

    def start(self):
        """
        Start the thread's activity.

        It must be called at most once per thread object. It arranges for the
        object's run() method to be invoked in a separate thread of control.

        This method will raise a RuntimeError if called more than once on the
        same thread object.
        """
        return super(PluggableNotifier, self).start()

    def stop(self):
        """
        Stop the thread.
        """
        return super(PluggableNotifier, self).stop()

    def unregister(self, name):
        """
        Unregister a callback with a given ``name``.

        Args:
            name (str): the name of the callback to be unregistered.

        Raises:
            KeyError: if ``name`` was not found in ``notifications``.
        """
        return super(PluggableNotifier, self).unregister(name=name)
