# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#

from __future__ import \
    absolute_import, division, print_function, unicode_literals

from htf.core import __version__
from htf.daqmx.edge_counter_input import EdgeCounterInput


class FrequencyInputInaccurate(object):
    """
    `FrequencyInputInaccurate` is used to measure a frequency using an
    `EdgeCounterInput`.

    In comparison to ``FrequencyInput`` frequencies below 100 Hz can be
    measured, too.
    """

    def __init__(self, descriptor):
        """
        Args:
            descriptor (str): The DAQmx device and line descriptor, eg.
                `cDaq1Mod1/ctr0`.
        """
        self.edgeCounter = EdgeCounterInput(descriptor=descriptor,
                                            initialCount=0,
                                            risingEdge=True,
                                            countUp=True)

    def sample(self, period=1.0, samples=1):
        """
        For `samples` times measure the count of edges within one `period` and
        convert it to Hz.

        Returns an array containing the measured frequencies.

        Args:
            period (float): the time in seconds between two samples.
            samples (int): the amount of samples.

        Returns:
            list of float: the list of samples.
        """

        edgeCounts = []

        for _ in range(samples):
            self.edgeCounter.reset()
            time.sleep(period)
            edgeCount = self.edgeCounter.get()
            edgeCounts.append(edgeCount)
        frequencies = list(map(lambda edgeCount: 1.0 / float(period) * edgeCount,
                               edgeCounts))

        return frequencies


if __name__ == "__main__":
    import time
    fi = FrequencyInputInaccurate(descriptor="Dev1/ctr0")

    frequencies = fi.sample(period=1, samples=10)

    print("frequencies:", frequencies)
