# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf._decorators import after as _after
from htf._decorators import before as _before
from htf._decorators import enqueueException as _enqueueException
from htf._decorators import meetsDOORSRequirements as _meetsDOORSRequirements
from htf._decorators import periodic as _periodic
from htf._decorators import raises as _raises
from htf._decorators import skip as _skip
from htf._decorators import skipIf as _skipIf
from htf._decorators import stacktrace as _stacktrace
from htf._decorators import timed as _timed


def after(afterFunction, *afterArgs, **afterKwargs):
    """
    The `@after` decorator decorates a method so that `afterFunction`
    is called after the decorated function is called itself.

    Args:
        afterFunction (callable): the function to be run after
            the decorated function.
        *afterArgs (tuple): positional arguments to be passed
            to ``afterFunction``.
        **afterKwargs (dict): keyword-arguments to be passed
            to ``afterFunction``.

    Usage::

        def runAfter(*args, **kwargs):
            print("runAfter", args, kwargs)
        @after(runAfter, 1, 2, 3, a="b")
        def function():
            print("function")
        function()
        # prints:
        # function
        # runAfter (1, 2, 3) {'a': 'b'}
    """
    return _after(afterFunction, *afterArgs, **afterKwargs)


def before(beforeFunction, *beforeArgs, **beforeKwargs):
    """
    The `@before` decorator decorates a method so that `beforeFunction`
    is called before the decorated function is called itself.

    Args:
        beforeFunction (callable): the function to be run before
            the decorated function.
        *beforeArgs (tuple): positional arguments to be passed
            to ``beforeFunction``.
        **beforeKwargs (dict): keyword-arguments to be passed
            to ``beforeFunction``.

    Usage::

        def runBefore(*args, **kwargs):
            print("runBefore", args, kwargs)
        @before(runBefore, 1, 2, 3, a="b")
        def function():
            print("function")
        function()
        # prints:
        # runBefore (1, 2, 3) {'a': 'b'}
        # function
    """
    return _before(beforeFunction, *beforeArgs, **beforeKwargs)


def enqueueException(queue):
    """
    Decorate a method to fetch it's exception that is enqueued into an
    exception queue.
    The enqueued exception can be handled elsewhere.
    The caught exception can be raised after enqueueing it.

    Just decorate you method with the queue to be used and
    every exception that is raised within the
    decorated method will be put into the queue
    before the exception is raised again.

    Args:
        queue (queue): the queue to enqueue the exception.

    Usage::

        @enqueueException(queue)
        def decoratedMethod():
            raise Exception("This is a test")
    """
    return _enqueueException(queue=queue)


def meetsDOORSRequirements(base_url, *requirements):
    """
    The ``@meetsDOORSRequirements`` decorator reports which requirements
    are fulfilled by a testcase in the test report
    shown in the :py:mod:`~htf.report.doors_testreport`
    and the :py:mod:`~htf.report.html_testreport.HTMLTestReport`.

    Args:
        base_url (str): the DOORS base url the links are created with.
        *requirement (tuple of str): a tuple of strings that name the
            fulfilled requirements, eg. "REQ_1", "REQ_2", etc.

    Usage::

        @meetsRequirements("doors://host:port/path-without-id-",
                           "REQ_1", "REQ_2")
        def test_withAUsefulName():
            pass
    """
    return _meetsDOORSRequirements(base_url, *requirements)


def periodic(period, maximumPeriod=None, runConditionLambda=None, raiseException=True):
    """
    Decorate a method to be run periodically.

    Args:
        period (float): the period in seconds.
        maximumPeriod=None (float): if set to a float >= `period`
            the periodic method may take up to `maximumPeriod` time
            without raising an exception. A warning is printed on
            stdout instead.
        runConditionLambda=None (callable): a callable (method or
            lambda expression) that has to return true while the method
            is run periodically.
        raiseException=True (bool): if set to ``True`` an exception is raised
            if the called method takes longer
            than the period (or ``maximumPeriod`` if set).

    Warning:
        Non-realtime operating system will not ensure timing accuracy.

    Usage::

        @periodic(period=1.0)
        def periodicallyCalledEverySecond():
            print("call")

    ``@periodic`` can also be used within classes::

        class ClassWithAPeriodicMethod():

            @periodic(period=1.0)
            def periodicallyCalledEverySecond(self):
                print("call")
    """
    return _periodic(period=period, maximumPeriod=maximumPeriod, runConditionLambda=runConditionLambda,
                     raiseException=raiseException)


def raises(*exceptions):
    """
    Decorate a method to catch different exceptions.

    Args:
        *exceptions (list of exceptions): a tuple of exceptions that are
            fetched.

    Usage::

        @raises(AssertionError)
        def test_failure(self):
            self.assertTrue(False)

        @raises(TimeoutException, UnknownException)
        def test_exceptions(self):
            raise TimeoutException("timeout")
            raise UnknownException("unknown exception")
    """
    return _raises(*exceptions)


def skip(reason):
    """
    Decorate a method to be skipped in view of the occasion.

    Args:
        reason (str): the reason to be put into the test report.

    Raises:
        SkipTest: to skip the test.

    Usage::

        @skip("This test is skipped in view of the occasion")
        def test_alwaysSkippedLambda():
            pass
    """
    return _skip(reason=reason)


def skipIf(condition, reason):
    """
    Decorate a method to be skipped. The ``condition`` is evaluated at runtime.

    Args:
        condition (bool or callable): the condition may be ``True``,
            ``False`` or a callable object that must return
            ``True`` or ``False``.
            The decorated test is skipped if ``condition`` is
            ``True`` or returns ``True``.
        reason (str): the reason to be put into the test report.

    Raises:
        SkipTest: to skip the test if ``condition`` is or returns ``True``.

    Usage::

        def skipTests():
            return True

        @skipIf(skipTests, "Skipped if skipTests returns True")
        def test_skippedIf():
            pass

        @skipIf(True, "Always skipped")
        def test_alwaysSkipped():
            pass

        @skipIf(False, "Never skipped")
        def test_neverSkipped():
            pass

        @skipIf(lambda: True, "Always skipped")
        def test_alwaysSkippedLambda():
            pass
    """
    return _skipIf(condition=condition, reason=reason)


def stacktrace(func):
    """
    The ``@stacktrace`` decorator decorates a method so that its call stack
    is printed to stdout every time it is called.
    This is useful for debugging.

    Usage::

        @stacktrace
        def function():
            pass

        function() # will print(the call stack to stdout)
    """
    return _stacktrace(func=func)


def timed(limit):
    """
    Decorate a method to ensure that is ends within a given time limit.

    Args:
        limit (float): the time limit in seconds.

    Usage::

        @timed(limit=0.1)
        def decoratedMethodThatFailes():
            time.sleep(0.2)

        @timed(limit=1.0)
        def decoratedMethodThatDoesNotFail():
            time.sleep(0.2)
    """
    return _timed(limit=limit)
