# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.mixins._delegation import DelegateCallbackMixin as _DelegateCallbackMixin
from htf.mixins._delegation import DelegateMixin as _DelegateMixin
from htf.mixins._delegation import DelegatorMixin as _DelegatorMixin


class DelegateCallbackMixin(_DelegateCallbackMixin):
    """
    ``DelegateCallbackMixin`` gives the possibility to user define
    setter and getter methods using a :py:class:`DelegateMixin`.
    """

    def __init__(self, setCallback, getCallback):
        """
        Args:
            setCallback (callable): the method to be called as a setter.
            getCallback (callable): the method to be called as a getter.
        """
        return super(DelegateCallbackMixin, self).__init__(setCallback=setCallback, getCallback=getCallback)

    def get(self):
        """
        The getter for a delegate.

        Note:
            This method is abstract.
        """
        return super(DelegateCallbackMixin, self).get()

    def set(self, value):
        """
        The setter for a delegate.

        Args:
            value: the value to be set.

        Note:
            This method is abstract.
        """
        return super(DelegateCallbackMixin, self).set(value=value)


class DelegateMixin(_DelegateMixin):
    """
    ``DelegateMixin`` defines :py:func:`set` and :py:func:`get` as methods that have
    to be overwritten by subclass.
    """

    def get(self):
        """
        The getter for a delegate.

        Note:
            This method is abstract.
        """
        return super(DelegateMixin, self).get()

    def set(self, value):
        """
        The setter for a delegate.

        Args:
            value: the value to be set.

        Note:
            This method is abstract.
        """
        return super(DelegateMixin, self).set(value=value)


class DelegatorMixin(_DelegatorMixin):
    """
    The ``DelegatorMixin`` automatically delegates calls for :py:func:`DelegateMixin.set` and
     :py:func:`DelegateMixin.get` to its members if they are instances of :py:class:`DelegateMixin`.
    """
