# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.powersupply._korad_ka3005p import KORAD_KA3005P as _KORAD_KA3005P
from htf.powersupply._korad_ka3005p import SetCurrentException as _SetCurrentException
from htf.powersupply._korad_ka3005p import SetOutputException as _SetOutputException
from htf.powersupply._korad_ka3005p import SetVoltageException as _SetVoltageException
from htf.powersupply._korad_ka3005p import TimeoutException as _TimeoutException


class KORAD_KA3005P(_KORAD_KA3005P):
    """
    ``KORAD_KA3005P`` is a hardware abstraction to the KORAD KA3005P power supply unit using a UART to control it.

    ``KORAD_KA3005P`` uses ``DelegatorMixin`` to automatically set and read it's members ``voltage`` and ``current``.
    """

    def __init__(self, port, debug=False):
        """
        Args:
            port (str): the comport to be used, eg. "COM3", 3 or "/dev/ttyUSB0", etc.
            debug=False (bool): if set to ``True`` debugging is enabled.
        """
        return super(KORAD_KA3005P, self).__init__(port=port, debug=debug)

    def close(self):
        """
        Close the serial member. This method is automatically called when :func:`__del__` is called.
        """
        return super(KORAD_KA3005P, self).close()

    def disableOutput(self):
        """
        Disable output.
        """
        return super(KORAD_KA3005P, self).disableOutput()

    def enableOutput(self):
        """
        Enable output.

        Raises:
            SetOutputException: if output was not set.
        """
        return super(KORAD_KA3005P, self).enableOutput()

    def getCurrentCurrent(self, channel=1):
        """
        Read the current current from device and return the result.

        Args:
            channel (int): the channel to use. Shall always be 1.

        Returns:
            float: the current current.
        """
        return super(KORAD_KA3005P, self).getCurrentCurrent(channel=channel)

    def getCurrentVoltage(self, channel=1):
        """
        Read current voltage from device and return the result.

        Args:
            channel=1 (int): the channel to use. Shall always be 1.

        Returns:
            float: the current voltage.
        """
        return super(KORAD_KA3005P, self).getCurrentVoltage(channel=channel)

    def getId(self):
        """
        Return the KORAD id.

        Returns:
            str: the KORAD id.
        """
        return super(KORAD_KA3005P, self).getId()

    def getStatus(self):
        """
        Read device status and return a dictionary.

        Returns:
            dict: the status dictionary containing the keys "ch1 mode", "ch2 mode", "tracking mode", "beep",
             "lock" and "output".
        """
        return super(KORAD_KA3005P, self).getStatus()

    def query(self, query, lengthOfAnswer=None, retries=3):
        """
        Send a command and wait for the answer.

        Args:
            query (str): the query to be sent.
            lengthOfAnswer=None (int): the maximum number of bytes to be received.
            retries=3: the number of retries.

        Returns:
            str: the answer.

        Raises:
            TimeoutException: if a communication time-out occured.
        """
        return super(KORAD_KA3005P, self).query(query=query, lengthOfAnswer=lengthOfAnswer, retries=retries)

    def sendCommand(self, command):
        """
        Directly send a command to the power supply unit.

        Args:
            command (str): the command to be sent.
        """
        return super(KORAD_KA3005P, self).sendCommand(command=command)

    def setCurrent(self, current, channel=1):
        """
        Set the output current for a given channel.

        Args:
            current (int, float or str): the current in units of amperes as int(), float() or string, eg. 0, 0.5,
             "0.5" or even "0.5 mA" work.
            channel (int): the channel to use. Shall always be 1.

        Raises:
            SetCurrentException: if current was not set.
        """
        return super(KORAD_KA3005P, self).setCurrent(current=current, channel=channel)

    def setVoltage(self, voltage, channel=1):
        """
        Set the output voltage for a given channel.

        If ``voltage`` is None the output is disabled.
        If ``voltage`` is not None the output is enabled.
        If ``voltage`` changes the output is first disabled, changed, and then enabled again.

        Args:
            voltage (float or None): the voltage in units of volts as int(), float() or string, eg. 23, 23.0,
             "23.0" or even "23.0 V" work.
            channel (int): the channel to use. Shall always be 1.

        Raises:
            SetVoltageException: if voltage was not set.
        """
        return super(KORAD_KA3005P, self).setVoltage(voltage=voltage, channel=channel)


class SetCurrentException(_SetCurrentException):
    """
    Exception that is raised if current was not set.
    """


class SetOutputException(_SetOutputException):
    """
    Exception that is raised if the output was not set.
    """


class SetVoltageException(_SetVoltageException):
    """
    Exception that is raised if voltage was not set.
    """


class TimeoutException(_TimeoutException):
    """
    Exception that is raised if a communication time-out occurred.
    """
