# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.report._doors_testreport import DOORSTestReport as _DOORSTestReport


class DOORSTestReport(_DOORSTestReport):
    """
    ``DOORSTestReport`` creates a DOORS test report.
    Links are automatically created from the created DOORS module
    to the fulfilled requirements.

    To state the fulfilled requirements the :py:func:`~htf.decorators.meetsDOORSRequirements` decorator should be used.

    Usage::

        from __future__ import absolute_import, division, print_function, unicode_literals
        from htf import TestLoader, TestCase, TestRunner, DOORSTestReport, meetsDOORSRequirements

        class Test(TestCase):
            @meetsDOORSRequirements("REQ_1", "REQ_2", "REQ_3", "TEST_1")
            def testWithDOORSLinks(self):
                pass

        suite = TestLoader().loadTestsFromTestCase(Test)

        result = TestRunner(title="DOORS test report",
                            reports=[
                                     DOORSTestReport(filename="doors.dxl",
                                                     reportModule="/path/to/report/module",
                                                     requirementsModules={
                                                         "REQ_.*" : "/path/to/requirements_module",
                                                         "TEST_.*" : "/path/to/test_specification",
                                                     },
                                                     linksModules={
                                                         "REQ_.*" : "/path/to/links/to/requirements_module",
                                                         "TEST_.*" : "/path/to/links/to/test_specification",
                                                         }
                                                     )
                                     ],
                            verbosity=2).run(suite)
    """

    def __init__(self, filename, reportModule, requirementsModules, linksModules=None, renderMetaData=True,
                 renderSteps=True):
        """
        Initialize a ``DOORSTestReport`` instance.

        Args:
            filename (str): the filename for the DXL test report.
            reportModule (str): the DOORS path to the report module.
            requirementsModules (dict): maps links to DOORS modules.
                The keys are regular expressions and the values are
                the desired target modules.
            linksModules={".*" : "DOORS Links"} (dict): maps requirements to desired link modules.
                The keys are regular expressions and the values are
                the desired link modules.
            renderMetaData=True (bool): if set to `True` metadata is rendered in DOORS
            renderSteps=True (bool): if set to `True` steps are rendered in DOORS
        """
        return super(DOORSTestReport, self).__init__(filename=filename, reportModule=reportModule,
                                                     requirementsModules=requirementsModules, linksModules=linksModules,
                                                     renderMetaData=renderMetaData, renderSteps=renderSteps)

    def render(self, data):
        """
        Generates and stores a DXL encoded TestReport.

        Args:
            data (dict): test result data
        """
        return super(DOORSTestReport, self).render(data=data)
