# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.report._json_testreport import JSONTestReport as _JSONTestReport
from htf.report._json_testreport import JSONUnicodeEncoder as _JSONUnicodeEncoder


class JSONTestReport(_JSONTestReport):
    """
    ``JSONTestReport`` creates a JSON test report.

    Usage::

        from __future__ import absolute_import, division, print_function, unicode_literals
        from htf import TestLoader, TestRunner, JSONTestReport

        suite = TestLoader().loadTestsFromTestCase(Test)
        result = TestRunner(title="A test", reports=JSONTestReport("test.json"), verbosity=2).run(suite)
    """

    def __init__(self, filename):
        """
        Initialize a ``JSONTestReport`` instance.

        Args:
            filename (str): the filename for the json test report.
        """
        return super(JSONTestReport, self).__init__(filename=filename)

    def render(self, data):
        """
        Generates and stores a JSON encoded TestReport.

        Args:
            data (dict): test result data
        """
        return super(JSONTestReport, self).render(data=data)


class JSONUnicodeEncoder(_JSONUnicodeEncoder):
    """
    Extensible JSON <http://json.org> encoder for Python data structures.

    Supports the following objects and types by default:

    +-------------------+---------------+
    | Python            | JSON          |
    +===================+===============+
    | dict              | object        |
    +-------------------+---------------+
    | list, tuple       | array         |
    +-------------------+---------------+
    | str               | string        |
    +-------------------+---------------+
    | int, float        | number        |
    +-------------------+---------------+
    | True              | true          |
    +-------------------+---------------+
    | False             | false         |
    +-------------------+---------------+
    | None              | null          |
    +-------------------+---------------+

    To extend this to recognize other objects, subclass and implement a
    ``.default()`` method with another method that returns a serializable
    object for ``o`` if possible, otherwise it should call the superclass
    implementation (to raise ``TypeError``).
    """

    def __init__(self, skipkeys=False, ensure_ascii=True, check_circular=True, allow_nan=True, sort_keys=False,
                 indent=None, separators=None, default=None):
        """
        Constructor for JSONEncoder, with sensible defaults.

        If skipkeys is false, then it is a TypeError to attempt
        encoding of keys that are not str, int, float or None.  If
        skipkeys is True, such items are simply skipped.

        If ensure_ascii is true, the output is guaranteed to be str
        objects with all incoming non-ASCII characters escaped.  If
        ensure_ascii is false, the output can contain non-ASCII characters.

        If check_circular is true, then lists, dicts, and custom encoded
        objects will be checked for circular references during encoding to
        prevent an infinite recursion (which would cause an OverflowError).
        Otherwise, no such check takes place.

        If allow_nan is true, then NaN, Infinity, and -Infinity will be
        encoded as such.  This behavior is not JSON specification compliant,
        but is consistent with most JavaScript based encoders and decoders.
        Otherwise, it will be a ValueError to encode such floats.

        If sort_keys is true, then the output of dictionaries will be
        sorted by key; this is useful for regression tests to ensure
        that JSON serializations can be compared on a day-to-day basis.

        If indent is a non-negative integer, then JSON array
        elements and object members will be pretty-printed with that
        indent level.  An indent level of 0 will only insert newlines.
        None is the most compact representation.

        If specified, separators should be an (item_separator, key_separator)
        tuple.  The default is (', ', ': ') if *indent* is ``None`` and
        (',', ': ') otherwise.  To get the most compact JSON representation,
        you should specify (',', ':') to eliminate whitespace.

        If specified, default is a function that gets called for objects
        that can't otherwise be serialized.  It should return a JSON encodable
        version of the object or raise a ``TypeError``.
        """
        return super(JSONUnicodeEncoder, self).__init__(skipkeys=skipkeys, ensure_ascii=ensure_ascii,
                                                        check_circular=check_circular, allow_nan=allow_nan,
                                                        sort_keys=sort_keys, indent=indent, separators=separators,
                                                        default=default)

    def default(self, obj):
        """
        Implement this method in a subclass such that it returns
        a serializable object for ``o``, or calls the base implementation
        (to raise a ``TypeError``).

        For example, to support arbitrary iterators, you could
        implement default like this::

            def default(self, o):
                try:
                    iterable = iter(o)
                except TypeError:
                    pass
                else:
                    return list(iterable)
                # Let the base class default method raise the TypeError
                return JSONEncoder.default(self, o)
        """
        return super(JSONUnicodeEncoder, self).default(obj=obj)

    def encode(self, o):
        """
        Return a JSON string representation of a Python data structure.

        >>> from json.encoder import JSONEncoder
        >>> JSONEncoder().encode({"foo": ["bar", "baz"]})
        '{"foo": ["bar", "baz"]}'
        """
        return super(JSONUnicodeEncoder, self).encode(o=o)

    def iterencode(self, o, _one_shot=False):
        """
        Encode the given object and yield each string
        representation as available.

        For example::

            for chunk in JSONEncoder().iterencode(bigobject):
                mysocket.write(chunk)
        """
        return super(JSONUnicodeEncoder, self).iterencode(o=o, _one_shot=_one_shot)
