# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, HILSTER GmbH, Germany - http://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.core import TestRunner as _TestRunner
from htf.core import TestResult as _TestResult


class TestRunner(_TestRunner):
    """
    A test runner class that displays renders in textual form, HTML form, XML form (like JUnit) and JSON form.

    It prints out the names of tests as they are run, errors as they
    occur, and a summary of the results at the end of the test run.
    """

    def __init__(self, title='Test report', reports=None, metadata=None, workingDirectory=None, verbosity=1,
                 failfast=False):
        """
        Initialise a ``TestRunner`` object.

        Parameters:
            title="Test report" (str): a title for the test report.
            reports: a list of test report instances (:py:class:`~htf.report.html_testreport.HTMLTestReport`,
                                                            :py:class:`~htf.report.xml_testreport.JunitXMLTestReport`,
                                                            :py:class:`~htf.report.json_testreport.JSONTestReport`,
                                                             etc.).
                                                            If left empty an HTMLTestReport is generated.
            metadata=None: metadata for the test run that can be shown in test report.
            workingDirectory (str): set working directory.
            verbosity=1 (int): verbosity.
            failfast=False (bool): if set to True, the test run stops after first failure or error.
        """
        return super(TestRunner, self).__init__(title=title, reports=reports, metadata=metadata,
                                                workingDirectory=workingDirectory, verbosity=verbosity,
                                                failfast=failfast)

    def run(self, test):
        """
        Run the given test case or test suite supplied by ``test``.

        Parameters:
            test: a TestSuite or a TestCase.
        """
        return super(TestRunner, self).run(test=test)


class TestResult(_TestResult):
    """
    ``TestResult`` offers additional (temporal) information on top of :py:class:`unittest.TextTestResult`.

    Adds per run statistics to the output, e.g. success, failure rates and runtimes.
    """

    def __init__(self, stream, descriptions, verbosity):
        """
        Expects the same arguments as :py:class:`unittest.TextTestResult`.
        """
        return super(TestResult, self).__init__(stream=stream, descriptions=descriptions, verbosity=verbosity)

    def addError(self, test, err):
        """
        Called when an error has occurred. 'err' is a tuple of values as
        returned by sys.exc_info().
        """
        return super(TestResult, self).addError(test=test, err=err)

    def addExpectedFailure(self, test, err):
        """
        Called when an expected failure/error occurred.
        """
        return super(TestResult, self).addExpectedFailure(test=test, err=err)

    def addFailure(self, test, err):
        """
        Called when an error has occurred. 'err' is a tuple of values as
        returned by sys.exc_info().
        """
        return super(TestResult, self).addFailure(test=test, err=err)

    def addSkip(self, test, reason):
        """
        Called when a test is skipped.
        """
        return super(TestResult, self).addSkip(test=test, reason=reason)

    def addSubTest(self, test, subtest, err):
        """
        Called at the end of a subtest.
        'err' is None if the subtest ended successfully, otherwise it's a
        tuple of values as returned by sys.exc_info().
        """
        return super(TestResult, self).addSubTest(test=test, subtest=subtest, err=err)

    def addSuccess(self, test):
        """
        Called when a test has completed successfully
        """
        return super(TestResult, self).addSuccess(test=test)

    def addUnexpectedSuccess(self, test):
        """
        Called when a test was expected to fail, but succeed.
        """
        return super(TestResult, self).addUnexpectedSuccess(test=test)

    def getDescription(self, test):
        return super(TestResult, self).getDescription(test=test)

    def printErrorList(self, flavour, errors):
        return super(TestResult, self).printErrorList(flavour=flavour, errors=errors)

    def printErrors(self):
        """
        Called by TestRunner after test run
        """
        return super(TestResult, self).printErrors()

    def startTest(self, test):
        """
        Called when the given test is about to be run
        """
        return super(TestResult, self).startTest(test=test)

    def startTestRun(self):
        """
        Called once before any tests are executed.

        See startTest for a method called before each test.
        """
        return super(TestResult, self).startTestRun()

    def stop(self):
        """
        Indicates that the tests should be aborted.
        """
        return super(TestResult, self).stop()

    def stopTest(self, test):
        """
        Called when the given test has been run
        """
        return super(TestResult, self).stopTest(test=test)

    def stopTestRun(self):
        """
        Called once after all tests are executed.

        See stopTest for a method called after each test.
        """
        return super(TestResult, self).stopTestRun()

    def wasSuccessful(self):
        """
        Tells whether or not this result was a success.
        """
        return super(TestResult, self).wasSuccessful()
